@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2022 Free Software Foundation, Inc.
+  Copyright (C) 1995-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -75,7 +75,7 @@
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdint.h>	/* intmax_t */
+#include <stdint.h>		/* intmax_t */
 #include <string.h>
 #include <unistd.h>
 #include <stdarg.h>
@@ -115,7 +115,7 @@ off_t restart_point = 0;
 struct sockaddr_storage myctladdr;
 struct sockaddr_storage hisctladdr;
 struct sockaddr_storage data_addr;
-socklen_t ctladdrlen;	/* Applies to all addresses.  */
+socklen_t ctladdrlen;		/* Applies to all addresses.  */
 
 /* For temporary resolving: hookup() and initconn()/noport.  */
 static char ia[INET6_ADDRSTRLEN];
@@ -189,9 +189,9 @@ hookup (char *host, int port)
   for (ai = res; ai != NULL; ai = ai->ai_next, ++again)
     {
       if (again)
-        {
+	{
 	  getnameinfo (ai->ai_addr, ai->ai_addrlen, ia, sizeof (ia),
-			NULL, 0, NI_NUMERICHOST);
+		       NULL, 0, NI_NUMERICHOST);
 	  error (0, 0, "Trying %s ...", ia);
 	}
 
@@ -202,7 +202,7 @@ hookup (char *host, int port)
       timeout.tv_sec = FTP_CONNECT_TIMEOUT;
       timeout.tv_usec = 0;
       if (setsockopt (s, SOL_SOCKET, SO_SNDTIMEO, &timeout,
-			sizeof (timeout)) < 0 && debug)
+		      sizeof (timeout)) < 0 && debug)
 	error (0, errno, "setsockopt (SO_SNDTIMEO)");
 
       if (connect (s, ai->ai_addr, ai->ai_addrlen) < 0)
@@ -210,7 +210,7 @@ hookup (char *host, int port)
 	  int oerrno = (errno != EINPROGRESS) ? errno : ETIMEDOUT;
 
 	  getnameinfo (ai->ai_addr, ai->ai_addrlen, ia, sizeof (ia),
-			NULL, 0, NI_NUMERICHOST);
+		       NULL, 0, NI_NUMERICHOST);
 	  error (0, oerrno, "connect to address %s", ia);
 	  close (s);
 	  s = -1;
@@ -221,12 +221,12 @@ hookup (char *host, int port)
       timeout.tv_sec = 0;
       timeout.tv_usec = 0;
       (void) setsockopt (s, SOL_SOCKET, SO_SNDTIMEO, &timeout,
-			  sizeof (timeout));
+			 sizeof (timeout));
 
       ctladdrlen = ai->ai_addrlen;
-      memmove ((caddr_t) &hisctladdr, ai->ai_addr, ai->ai_addrlen);
+      memmove ((caddr_t) & hisctladdr, ai->ai_addr, ai->ai_addrlen);
       break;
-    } /* for (ai = ai->ai_next) */
+    }				/* for (ai = ai->ai_next) */
 
   if (res)
     freeaddrinfo (res);
@@ -249,7 +249,7 @@ hookup (char *host, int port)
 #if defined IP_TOS && defined IPPROTO_IP && defined IPTOS_LOWDELAY
   tos = IPTOS_LOWDELAY;
   if (myctladdr.ss_family == AF_INET &&
-	setsockopt (s, IPPROTO_IP, IP_TOS, (char *) &tos, sizeof (int)) < 0)
+      setsockopt (s, IPPROTO_IP, IP_TOS, (char *) &tos, sizeof (int)) < 0)
     error (0, errno, "setsockopt TOS (ignored)");
 #endif
 
@@ -535,7 +535,7 @@ getreply (int expecteof)
 	    }
 	  if (dig < 4 && isdigit (c))
 	    code = code * 10 + (c - '0');
-	  if (!pflag && (code == 227 || code == 228 || code == 229)) /* PASV || LPSV || EPSV */
+	  if (!pflag && (code == 227 || code == 228 || code == 229))	/* PASV || LPSV || EPSV */
 	    pflag = 1;
 	  if (dig > 4 && pflag == 1 && isdigit (c))
 	    pflag = 2;
@@ -543,7 +543,7 @@ getreply (int expecteof)
 	    {
 	      if (c != '\r' && c != ')')
 		{
-		  if (pt < &pasv[sizeof(pasv) - 1])
+		  if (pt < &pasv[sizeof (pasv) - 1])
 		    *pt++ = c;
 		}
 	      else
@@ -704,7 +704,7 @@ sendrequest (char *cmd, char *local, char *remote, int printnames)
 	  code = -1;
 	  return;
 	}
-	blksize = st.st_blksize;
+      blksize = st.st_blksize;
     }
   if (initconn ())
     {
@@ -926,7 +926,8 @@ abortrecv (int sig MAYBE_UNUSED)
 }
 
 void
-recvrequest (char *cmd, char *local, char *remote, char *lmode, int printnames)
+recvrequest (char *cmd, char *local, char *remote, char *lmode,
+	     int printnames)
 {
   FILE *fout, *din = 0;
   int (*closefunc) (FILE *);
@@ -1151,7 +1152,7 @@ recvrequest (char *cmd, char *local, char *remote, char *lmode, int printnames)
 	      /* Explain our failure.  */
 	      if (ch == EOF)
 		printf ("Action not taken: offset %jd is outside of %s.\n",
-		       restart_point, local);
+			restart_point, local);
 	      else
 		error (0, errno, "local: %s", local);
 
@@ -1270,7 +1271,7 @@ initconn (void)
   socklen_t len;
   int on = 1;
   uint32_t a0, a1, a2, a3, p0, p1, port;
-  uint32_t af, hal, h[16], pal; /* RFC 1639: LPSV resonse.  */
+  uint32_t af, hal, h[16], pal;	/* RFC 1639: LPSV resonse.  */
   struct sockaddr_in *data_addr_sa4 = (struct sockaddr_in *) &data_addr;
   struct sockaddr_in6 *data_addr_sa6 = (struct sockaddr_in6 *) &data_addr;
 
@@ -1293,42 +1294,42 @@ initconn (void)
        *   then fall back to PASV/LPSV.
        */
       switch (myctladdr.ss_family)
-        {
-	  case AF_INET:
-	    if (doepsv4 && command ("EPSV") == COMPLETE)
-	      {
-	        good_epsv = 1;
-	        break;
-	      }
-	    if (doepsv4)
-	      {
-		/* When arriving here, EPSV failed. Prevent new attempts.  */
-		doepsv4 = 0;
-	      }
-	    if (command ("PASV") == COMPLETE)
-		break;
-	    if (command ("LPSV") == COMPLETE)
-	      {
-		good_lpsv = 1;
-		break;
-	      }
-	    printf ("Passive mode refused.\n");
-	    goto bad;
-	    break;
-	  case AF_INET6:
-	    if (command ("EPSV") == COMPLETE)
-	      {
-		good_epsv = 1;
-		break;
-	      }
-	    if (command ("LPSV") == COMPLETE)
-	      {
-		good_lpsv = 1;
-		break;
-	      }
-	    printf ("Passive mode refused.\n");
-	    goto bad;
+	{
+	case AF_INET:
+	  if (doepsv4 && command ("EPSV") == COMPLETE)
+	    {
+	      good_epsv = 1;
+	      break;
+	    }
+	  if (doepsv4)
+	    {
+	      /* When arriving here, EPSV failed. Prevent new attempts.  */
+	      doepsv4 = 0;
+	    }
+	  if (command ("PASV") == COMPLETE)
 	    break;
+	  if (command ("LPSV") == COMPLETE)
+	    {
+	      good_lpsv = 1;
+	      break;
+	    }
+	  printf ("Passive mode refused.\n");
+	  goto bad;
+	  break;
+	case AF_INET6:
+	  if (command ("EPSV") == COMPLETE)
+	    {
+	      good_epsv = 1;
+	      break;
+	    }
+	  if (command ("LPSV") == COMPLETE)
+	    {
+	      good_lpsv = 1;
+	      break;
+	    }
+	  printf ("Passive mode refused.\n");
+	  goto bad;
+	  break;
 	}
 
       if (good_epsv)
@@ -1341,21 +1342,21 @@ initconn (void)
 	  if (sscanf (pasv, "%u|", &port) != 1)
 	    {
 	      printf ("Extended passive mode scan failure. "
-			"Should not happen!\n");
+		      "Should not happen!\n");
 	      (void) command ("ABOR");	/* Cancel any open connection.  */
 	      goto bad;
 	    }
 	  data_addr = hisctladdr;
 	  switch (data_addr.ss_family)
 	    {
-	      case AF_INET:
-		data_addr_sa4->sin_port = htons (port);
-		break;
-	      case AF_INET6:
-		data_addr_sa6->sin6_port = htons (port);
-		break;
+	    case AF_INET:
+	      data_addr_sa4->sin_port = htons (port);
+	      break;
+	    case AF_INET6:
+	      data_addr_sa6->sin6_port = htons (port);
+	      break;
 	    }
-	} /* EPSV */
+	}			/* EPSV */
       else if (good_lpsv)
 	{
 	  /* LPSV: IPv4 or IPv6
@@ -1368,11 +1369,12 @@ initconn (void)
 
 	  if (myctladdr.ss_family == AF_INET)
 	    {
-	      if ((sscanf (pasv, "%u," /* af */
-				"%u,%u,%u,%u,%u," /* hal, h[4] */
-				"%u,%u,%u", /* pal, p0, p1 */
-				&af, &hal, &h[0], &h[1], &h[2], &h[3], &pal, &p0, &p1) != 9)
-		  || (/* Strong checking */ af != 4 || hal != 4 || pal != 2) )
+	      if ((sscanf (pasv, "%u,"	/* af */
+			   "%u,%u,%u,%u,%u,"	/* hal, h[4] */
+			   "%u,%u,%u",	/* pal, p0, p1 */
+			   &af, &hal, &h[0], &h[1], &h[2], &h[3], &pal, &p0,
+			   &p1) != 9) || ( /* Strong checking */ af != 4
+					  || hal != 4 || pal != 2))
 		{
 		  printf ("Passive mode address scan failure. "
 			  "Shouldn't happen!\n");
@@ -1380,33 +1382,36 @@ initconn (void)
 		  goto bad;
 		}
 	      for (j = 0; j < 4; ++j)
-		h[j] &= 0xff; /* Mask only the significant bits.  */
+		h[j] &= 0xff;	/* Mask only the significant bits.  */
 
 	      data_addr.ss_family = AF_INET;
 	      data_addr_sa4->sin_port =
-		  htons (((p0 & 0xff) << 8) | (p1 & 0xff));
+		htons (((p0 & 0xff) << 8) | (p1 & 0xff));
 
+	      {
+		uint32_t *pu32 =
+		  (uint32_t *) & data_addr_sa4->sin_addr.s_addr;
+		pu32[0] =
+		  htonl ((h[0] << 24) | (h[1] << 16) | (h[2] << 8) | h[3]);
+	      }
+	      if (data_addr_sa4->sin_addr.s_addr
+		  != ((struct sockaddr_in *) &hisctladdr)->sin_addr.s_addr)
 		{
-		  uint32_t *pu32 = (uint32_t *) &data_addr_sa4->sin_addr.s_addr;
-		  pu32[0] = htonl ( (h[0] << 24) | (h[1] << 16) | (h[2] << 8) | h[3]);
+		  printf ("Passive mode address mismatch.\n");
+		  (void) command ("ABOR");	/* Cancel any open connection.  */
+		  goto bad;
 		}
-		if (data_addr_sa4->sin_addr.s_addr
-		    != ((struct sockaddr_in *) &hisctladdr)->sin_addr.s_addr)
-		  {
-		    printf ("Passive mode address mismatch.\n");
-		    (void) command ("ABOR");	/* Cancel any open connection.  */
-		    goto bad;
-		  }
-	    } /* LPSV IPv4 */
-	  else /* IPv6 */
+	    }			/* LPSV IPv4 */
+	  else			/* IPv6 */
 	    {
-	      if ((sscanf (pasv, "%u," /* af */
-				"%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u," /* hal, h[16] */
-				"%u,%u,%u", /* pal, p0, p1 */
-				&af, &hal, &h[0], &h[1], &h[2], &h[3], &h[4], &h[5], &h[6], &h[7],
-				&h[8], &h[9], &h[10], &h[11], &h[12], &h[13], &h[14], &h[15],
-				&pal, &p0, &p1) != 21)
-		  || (/* Strong checking */ af != 6 || hal != 16 || pal != 2) )
+	      if ((sscanf (pasv, "%u,"	/* af */
+			   "%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,"	/* hal, h[16] */
+			   "%u,%u,%u",	/* pal, p0, p1 */
+			   &af, &hal, &h[0], &h[1], &h[2], &h[3], &h[4],
+			   &h[5], &h[6], &h[7], &h[8], &h[9], &h[10], &h[11],
+			   &h[12], &h[13], &h[14], &h[15], &pal, &p0,
+			   &p1) != 21) || ( /* Strong checking */ af != 6
+					   || hal != 16 || pal != 2))
 		{
 		  printf ("Passive mode address scan failure. "
 			  "Shouldn't happen!\n");
@@ -1414,32 +1419,38 @@ initconn (void)
 		  goto bad;
 		}
 	      for (j = 0; j < 16; ++j)
-		h[j] &= 0xff; /* Mask only the significant bits.  */
+		h[j] &= 0xff;	/* Mask only the significant bits.  */
 
 	      data_addr.ss_family = AF_INET6;
 	      data_addr_sa6->sin6_port =
-		  htons (((p0 & 0xff) << 8) | (p1 & 0xff));
+		htons (((p0 & 0xff) << 8) | (p1 & 0xff));
 
+	      {
+		uint32_t *pu32 =
+		  (uint32_t *) & data_addr_sa6->sin6_addr.s6_addr;
+		pu32[0] =
+		  htonl ((h[0] << 24) | (h[1] << 16) | (h[2] << 8) | h[3]);
+		pu32[1] =
+		  htonl ((h[4] << 24) | (h[5] << 16) | (h[6] << 8) | h[7]);
+		pu32[2] =
+		  htonl ((h[8] << 24) | (h[9] << 16) | (h[10] << 8) | h[11]);
+		pu32[3] =
+		  htonl ((h[12] << 24) | (h[13] << 16) | (h[14] << 8) |
+			 h[15]);
+	      }
+	      if (data_addr_sa6->sin6_addr.s6_addr
+		  != ((struct sockaddr_in6 *) &hisctladdr)->sin6_addr.s6_addr)
 		{
-		  uint32_t *pu32 = (uint32_t *) &data_addr_sa6->sin6_addr.s6_addr;
-		  pu32[0] = htonl ( (h[0] << 24) | (h[1] << 16) | (h[2] << 8) | h[3]);
-		  pu32[1] = htonl ( (h[4] << 24) | (h[5] << 16) | (h[6] << 8) | h[7]);
-		  pu32[2] = htonl ( (h[8] << 24) | (h[9] << 16) | (h[10] << 8) | h[11]);
-		  pu32[3] = htonl ( (h[12] << 24) | (h[13] << 16) | (h[14] << 8) | h[15]);
+		  printf ("Passive mode address mismatch.\n");
+		  (void) command ("ABOR");	/* Cancel any open connection.  */
+		  goto bad;
 		}
-		if (data_addr_sa6->sin6_addr.s6_addr
-		    != ((struct sockaddr_in6 *) &hisctladdr)->sin6_addr.s6_addr)
-		  {
-		    printf ("Passive mode address mismatch.\n");
-		    (void) command ("ABOR");	/* Cancel any open connection.  */
-		    goto bad;
-		  }
-	    } /* LPSV IPv6 */
+	    }			/* LPSV IPv6 */
 	}
-      else /* !EPSV && !LPSV */
-	{ /* PASV */
+      else			/* !EPSV && !LPSV */
+	{			/* PASV */
 	  if (myctladdr.ss_family == AF_INET)
-	    { /* PASV */
+	    {			/* PASV */
 	      if (sscanf (pasv, "%u,%u,%u,%u,%u,%u",
 			  &a0, &a1, &a2, &a3, &p0, &p1) != 6)
 		{
@@ -1450,10 +1461,10 @@ initconn (void)
 		}
 	      data_addr.ss_family = AF_INET;
 	      data_addr_sa4->sin_addr.s_addr =
-		  htonl ( (a0 << 24) | ((a1 & 0xff) << 16)
-			 | ((a2 & 0xff) << 8) | (a3 & 0xff) );
+		htonl ((a0 << 24) | ((a1 & 0xff) << 16)
+		       | ((a2 & 0xff) << 8) | (a3 & 0xff));
 	      data_addr_sa4->sin_port =
-		  htons (((p0 & 0xff) << 8) | (p1 & 0xff));
+		htons (((p0 & 0xff) << 8) | (p1 & 0xff));
 	      if (data_addr_sa4->sin_addr.s_addr
 		  != ((struct sockaddr_in *) &hisctladdr)->sin_addr.s_addr)
 		{
@@ -1461,14 +1472,15 @@ initconn (void)
 		  (void) command ("ABOR");	/* Cancel any open connection.  */
 		  goto bad;
 		}
-	    } /* PASV */
+	    }			/* PASV */
 	  else
 	    {
 	      /* Catch all impossible cases.  */
-	      printf ("Passive mode address scan failure. Shouldn't happen!\n");
+	      printf
+		("Passive mode address scan failure. Shouldn't happen!\n");
 	      goto bad;
 	    }
-	} /* PASV */
+	}			/* PASV */
 
       if (connect (data, (struct sockaddr *) &data_addr, ctladdrlen) < 0)
 	{
@@ -1478,7 +1490,7 @@ initconn (void)
 #if defined IP_TOS && defined IPPROTO_IP && defined IPTOS_THROUGHPUT
       on = IPTOS_THROUGHPUT;
       if (data_addr.ss_family == AF_INET &&
-	   setsockopt (data, IPPROTO_IP, IP_TOS, (char *) &on,
+	  setsockopt (data, IPPROTO_IP, IP_TOS, (char *) &on,
 		      sizeof (int)) < 0)
 	perror ("ftp: setsockopt TOS (ignored)");
 #endif
@@ -1491,12 +1503,12 @@ noport:
     /* Let the system pick a port.  */
     switch (myctladdr.ss_family)
       {
-	case AF_INET:
-	  data_addr_sa4->sin_port = 0;
-	  break;
-	case AF_INET6:
-	  data_addr_sa6->sin6_port = 0;
-	  break;
+      case AF_INET:
+	data_addr_sa4->sin_port = 0;
+	break;
+      case AF_INET6:
+	data_addr_sa6->sin6_port = 0;
+	break;
       }
 
   if (data != -1)
@@ -1541,14 +1553,14 @@ noport:
        *   IPv4: EPRT, PORT, LPRT
        *   IPv6: EPRT, LPRT
        */
-      result = ERROR;	/* For success detection.  */
+      result = ERROR;		/* For success detection.  */
       if (data_addr.ss_family != AF_INET || doepsv4)
 	{
 	  char *p;
 	  /* Use EPRT mode.  */
 	  getnameinfo ((struct sockaddr *) &data_addr, ctladdrlen,
-			ia, sizeof (ia), portstr, sizeof (portstr),
-			NI_NUMERICHOST | NI_NUMERICSERV);
+		       ia, sizeof (ia), portstr, sizeof (portstr),
+		       NI_NUMERICHOST | NI_NUMERICSERV);
 	  /* Remove IPv6 link local address postfix */
 	  p = strchr (ia, '%');
 	  if (p)
@@ -1579,22 +1591,22 @@ noport:
 
 	  switch (data_addr.ss_family)
 	    {
-	      case AF_INET:
-		h = (uint8_t *) &data_addr_sa4->sin_addr;
-		p = (uint8_t *) &data_addr_sa4->sin_port;
-		result = command ("LPRT 4,4,%u,%u,%u,%u,2,%u,%u",
-				  h[0], h[1], h[2], h[3], p[0], p[1]);
-		break;
-	      case AF_INET6:
-		h = (uint8_t *) &data_addr_sa6->sin6_addr;
-		p = (uint8_t *) &data_addr_sa6->sin6_port;
-		result = command ("LPRT 6,16," /* af, hal */
-				  "%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u," /* h[16] */
-				  "2,%u,%u", /* pal, p[2] */
-				  h[0], h[1], h[2], h[3], h[4], h[5], h[6], h[7],
-				  h[8], h[9], h[10], h[11], h[12], h[13], h[14], h[15],
-				  p[0], p[1]);
-		break;
+	    case AF_INET:
+	      h = (uint8_t *) & data_addr_sa4->sin_addr;
+	      p = (uint8_t *) & data_addr_sa4->sin_port;
+	      result = command ("LPRT 4,4,%u,%u,%u,%u,2,%u,%u",
+				h[0], h[1], h[2], h[3], p[0], p[1]);
+	      break;
+	    case AF_INET6:
+	      h = (uint8_t *) & data_addr_sa6->sin6_addr;
+	      p = (uint8_t *) & data_addr_sa6->sin6_port;
+	      result = command ("LPRT 6,16,"	/* af, hal */
+				"%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,%u,"	/* h[16] */
+				"2,%u,%u",	/* pal, p[2] */
+				h[0], h[1], h[2], h[3], h[4], h[5], h[6],
+				h[7], h[8], h[9], h[10], h[11], h[12], h[13],
+				h[14], h[15], p[0], p[1]);
+	      break;
 	    }
 	}
 
@@ -1611,7 +1623,7 @@ noport:
 #if defined IP_TOS && defined IPPROTO_IP && defined IPTOS_THROUGHPUT
   on = IPTOS_THROUGHPUT;
   if (data_addr.ss_family == AF_INET &&
-	setsockopt (data, IPPROTO_IP, IP_TOS, (char *) &on, sizeof (int)) < 0)
+      setsockopt (data, IPPROTO_IP, IP_TOS, (char *) &on, sizeof (int)) < 0)
     error (0, errno, "setsockopt TOS (ignored)");
 #endif
   return (0);
@@ -1644,7 +1656,7 @@ dataconn (char *lmode)
 #if defined IP_TOS && defined IPPROTO_IP && defined IPTOS_THROUGHPUT
   tos = IPTOS_THROUGHPUT;
   if (from.ss_family == AF_INET &&
-	setsockopt (s, IPPROTO_IP, IP_TOS, (char *) &tos, sizeof (int)) < 0)
+      setsockopt (s, IPPROTO_IP, IP_TOS, (char *) &tos, sizeof (int)) < 0)
     error (0, errno, "setsockopt TOS (ignored)");
 #endif
   return (fdopen (data, lmode));
@@ -1729,11 +1741,11 @@ pswitch (int flag)
     int mapflg;
     char *mi;
     char *mo;
-  } proxstruct =
-  {
-  0}, tmpstruct =
-  {
-  0};
+  } proxstruct = {
+    0
+  }, tmpstruct = {
+    0
+  };
   struct comvars *ip, *op;
 
   abrtflag = 0;
@@ -2012,12 +2024,12 @@ gunique (char *local)
 	ext++;
 
       if (stat (new, &st) != 0)
-        {
-          if (errno == ENOENT)
-            return new;
-          else
-            return 0;
-        }
+	{
+	  if (errno == ENOENT)
+	    return new;
+	  else
+	    return 0;
+	}
 
       if (ext != '0')
 	cp--;
