@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2022 Free Software Foundation, Inc.
+  Copyright (C) 2000-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -133,13 +133,12 @@ checkuser (const char *filename, const char *name, char **path)
 			  }
 		    }
 		}
-	      continue;	/* No match, or failure.  */
+	      continue;		/* No match, or failure.  */
 	    }
 
 	  /* User name ends at the first blank character.  */
 	  if (strncasecmp (p, name, strlen (name)) == 0
-	      && (p[strlen (name)] == 0
-		  || isblank (p[strlen (name)])))
+	      && (p[strlen (name)] == 0 || isblank (p[strlen (name)])))
 	    {
 	      p += strlen (name);
 	      found = 1;
