@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2000-2022 Free Software Foundation, Inc.
+  Copyright (C) 2000-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -46,7 +46,7 @@ static void reapchild (int);
 #ifndef DEFPORT
 # ifdef IPPORT_FTP
 #  define DEFPORT IPPORT_FTP
-# else /* !IPPORT_FTP */
+# else/* !IPPORT_FTP */
 #  define DEFPORT 21
 # endif
 #endif /* !DEFPORT */
@@ -73,18 +73,16 @@ check_host (struct sockaddr *sa, socklen_t len)
   char addr[INET6_ADDRSTRLEN];
   char name[NI_MAXHOST];
 
-  if (sa->sa_family != AF_INET
-      && sa->sa_family != AF_INET6)
+  if (sa->sa_family != AF_INET && sa->sa_family != AF_INET6)
     return 1;
 
-  (void) getnameinfo(sa, len, addr, sizeof (addr), NULL, 0, NI_NUMERICHOST);
-  err = getnameinfo(sa, len, name, sizeof (name), NULL, 0, NI_NAMEREQD);
+  (void) getnameinfo (sa, len, addr, sizeof (addr), NULL, 0, NI_NUMERICHOST);
+  err = getnameinfo (sa, len, name, sizeof (name), NULL, 0, NI_NAMEREQD);
   if (!err)
     {
       if (!hosts_ctl ("ftpd", name, addr, STRING_UNKNOWN))
 	{
-	  syslog (deny_severity, "tcpwrappers rejected: %s [%s]",
-		  name, addr);
+	  syslog (deny_severity, "tcpwrappers rejected: %s [%s]", name, addr);
 	  return 0;
 	}
     }
@@ -244,7 +242,7 @@ server_mode (const char *pidfile, struct sockaddr *phis_addr,
 #ifndef HAVE_FORK
   _exit (execvp (argv[0], argv));
 #else
-  (void) argv;		/* Silence warnings.  */
+  (void) argv;			/* Silence warnings.  */
 #endif
 
   return fd;
