@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2022 Free Software Foundation, Inc.
+  Copyright (C) 1995-2023 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -178,9 +178,8 @@ message (char *string)
       wmove (my_win.x_win, current_line % my_win.x_nlines, 0);
       wrefresh (my_win.x_win);
     }
-  else
-    if (string && string[0])
-      printf ("[%s]\n", string);
+  else if (string && string[0])
+    printf ("[%s]\n", string);
 
   return 0;
 }
